validate_output_path

Function validate_output_path 

pub fn validate_output_path(path: &Path) -> Result<()>
Validate that path is inside the user’s home directory — used when ZAG_USER_HOME_DIR is set (multi-user zag serve mode) to keep a user from writing outside their sandbox. In direct CLI mode ZAG_USER_HOME_DIR is unset and this function is a no-op.