pub struct PlanResult {
pub text: Option<String>,
pub written_to: Option<PathBuf>,
}Expand description
Result of running a plan.
Fields
text: Option<String>Captured plan text, when output was set (otherwise the plan was
streamed to stdout by the underlying agent and nothing is captured
here).
written_to: Option<PathBuf>Path the plan was written to, when output was set.