Functions
- check_
exit_ status - Log stderr and bail on non-zero exit status.
- handle_
output - Handle stderr logging and exit status checking for a completed
Output. - log_
stderr_ text - Log non-empty stderr text.
- run_
captured - Run a command capturing stdout and stderr, returning stdout text on success.
- run_
with_ captured_ stderr - Run a command with stderr captured.
- spawn_
with_ captured_ stderr - Spawn a command with stderr captured, but stdout piped for reading.
- wait_
with_ stderr - Wait for a child process and handle its captured stderr.