pub struct LiveLogContext {
pub root: Option<String>,
pub provider_session_id: Option<String>,
pub workspace_path: Option<String>,
pub started_at: DateTime<Utc>,
pub is_worktree: bool,
}Fields
root: Option<String>provider_session_id: Option<String>workspace_path: Option<String>started_at: DateTime<Utc>is_worktree: boolWhen true, the session is running in a unique worktree and the adapter can reliably detect session clears by watching for new files.